@@ -4,8 +4,9 @@
 
 //-----------------------------------------------------------------------------
 // Image definitions
-#define IMAGE_FILE_NAME "/home/user/MyDocs/.images/image.jpg"
-#define IMAGE_FILE_TYPE "JPG"
+#define IMAGE_FILE_NAME "/home/user/MyDocs/.images/image.png"
+//#define IMAGE_FILE_TYPE "JPG"
+#define IMAGE_FILE_TYPE "PNG"
 
 //-----------------------------------------------------------------------------
 #endif // DEFINITIONS_H
